cache_clear: Clear cached simulation data

View source: R/load_data_external.R

cache_clearR Documentation

Clear cached simulation data

Description

[Experimental]

Removes locally cached simulation data (~150 MB) used by plan_sample_size(). Data will be automatically re-downloaded on next use of sample size planning functions.

This function is useful when:

  • You want to free up disk space

  • The cached data may be outdated and you want to force a fresh download

  • Troubleshooting cache-related issues

Usage

cache_clear()

Value

Invisibly returns TRUE if cache was cleared, FALSE if no cache existed.

Examples

## Not run: 
# Clear cache
cache_clear()

## End(Not run)

sprtt documentation built on May 6, 2026, 5:06 p.m.