download_sample_size_data: Download simulation data for sample size planning

View source: R/load_data_external.R

download_sample_size_dataR Documentation

Download simulation data for sample size planning

Description

[Experimental]

Downloads pre-computed simulation results from GitHub releases. Data is cached locally and only needs to be downloaded once.

Data is hosted at: MeikeSteinhilber/sprtt_plan_sample_size

Usage

download_sample_size_data(force = FALSE)

Arguments

force

Logical. If TRUE, re-download even if data exists. Default FALSE.

Value

Invisibly returns the path to the cached data file.

Examples

## Not run: 
# Download data (only needed once)
download_sample_size_data()

# Force re-download (e.g., after data update)
download_sample_size_data(force = TRUE)

## End(Not run)


sprtt documentation built on May 6, 2026, 5:06 p.m.