sprtt-package: sprtt: Sequential Probability Ratio Tests Toolbox

sprtt-packageR Documentation

sprtt: Sequential Probability Ratio Tests Toolbox

Description

logo

A toolbox for Sequential Probability Ratio Tests (SPRT) based on Wald (1945) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.2134/agronj1947.00021962003900070011x")}. SPRTs are applied during the sampling process, ideally after each observation, and at every stage return a decision to either continue sampling or terminate and accept one of the specified hypotheses. The 'seq_ttest()' function performs one-sample, two-sample, and paired t-tests for one- and two-sided hypotheses (Schnuerch & Erdfelder (2019) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1037/met0000234")}). The 'seq_anova()' function performs a sequential one-way fixed effects ANOVA (Steinhilber et al. (2024) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1037/met0000677")}). The 'plan_sample_size()' function helps plan sequential studies by simulating required sample sizes across a range of effect sizes. For more information, see the vignettes browseVignettes(package = "sprtt") or the package website https://meikesteinhilber.github.io/sprtt/.

Author(s)

Maintainer: Meike Snijder-Steinhilber Meike.Steinhilber@aol.com (ORCID)

Authors:

  • Martin Schnuerch (ORCID) [thesis advisor]

  • Anna-Lena Schubert (ORCID) [thesis advisor]

See Also

Useful links:


sprtt documentation built on May 6, 2026, 5:06 p.m.