sub-seq_ttest_results-method: Method to retrieve the contents of a slot of an object of the...

[,seq_ttest_results-methodR Documentation

Method to retrieve the contents of a slot of an object of the seq_ttest_results class.

Description

Method to retrieve the contents of a slot of an object of the seq_ttest_results class.

Usage

## S4 method for signature 'seq_ttest_results'
x[i, j, drop]

Arguments

x

the seq_ttest_results object.

i

indices indicating elements to extract.

j

not used.

drop

not used.

seq_ttest_results

the corresponding class to this method.

Value

Returns the contents of the specified slot. For more information, see the documentation for the seq_ttest_results class.


sprtt documentation built on May 6, 2026, 5:06 p.m.