View source: R/load_data_external.R
| cache_clear | R Documentation |
Removes locally cached simulation data (~150 MB) used by plan_sample_size().
Data will be automatically re-downloaded on next use of sample size planning functions.
This function is useful when:
You want to free up disk space
The cached data may be outdated and you want to force a fresh download
Troubleshooting cache-related issues
cache_clear()
Invisibly returns TRUE if cache was cleared, FALSE if no cache existed.
## Not run:
# Clear cache
cache_clear()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.