View source: R/load_data_external.R
| download_sample_size_data | R Documentation |
Downloads pre-computed simulation results from GitHub releases. Data is cached locally and only needs to be downloaded once.
Data is hosted at: MeikeSteinhilber/sprtt_plan_sample_size
download_sample_size_data(force = FALSE)
force |
Logical. If TRUE, re-download even if data exists. Default FALSE. |
Invisibly returns the path to the cached data file.
## Not run:
# Download data (only needed once)
download_sample_size_data()
# Force re-download (e.g., after data update)
download_sample_size_data(force = TRUE)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.